Sel

Struct Sel 

pub struct Sel { /* private fields */ }

Implementations

Source

impl Sel

pub fn register(name: &str) -> Sel

Registers a method with the Objective-C runtime system, maps the method name to a selector, and returns the selector value.

pub fn name(&self) -> &str

Returns the name of the method specified by self.

pub unsafe fn from_ptr(ptr: *const c_void) -> Sel

Wraps a raw pointer to a selector into a Sel object.

This is almost never what you want; use Sel::register() instead.

pub fn as_ptr(&self) -> *const c_void

Returns a pointer to the raw selector.